aboutsummaryrefslogtreecommitdiff
path: root/include/llvm/Module.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/Module.h')
-rw-r--r--include/llvm/Module.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/include/llvm/Module.h b/include/llvm/Module.h
index 846b47f057..c53ee4eb9a 100644
--- a/include/llvm/Module.h
+++ b/include/llvm/Module.h
@@ -32,14 +32,16 @@ class SymbolTable;
template<> struct ilist_traits<Function>
: public SymbolTableListTraits<Function, Module, Module> {
- // createNode is used to create a node that marks the end of the list...
- static Function *createNode();
+ // createSentinal is used to create a node that marks the end of the list.
+ static Function *createSentinal();
+ static void destroySentinal(Function *F) { delete F; }
static iplist<Function> &getList(Module *M);
};
template<> struct ilist_traits<GlobalVariable>
: public SymbolTableListTraits<GlobalVariable, Module, Module> {
- // createNode is used to create a node that marks the end of the list...
- static GlobalVariable *createNode();
+ // createSentinal is used to create a node that marks the end of the list.
+ static GlobalVariable *createSentinal();
+ static void destroySentinal(GlobalVariable *GV) { delete GV; }
static iplist<GlobalVariable> &getList(Module *M);
};